SQL Statements and Expressions API — SQLAlchemy 0.9 Documentation

# SQLAlchemy 0.9 Documentation

Search:
Release: 0.9.0 | Release Date: December 30, 2013

# SQL Statements and Expressions API

This section presents the API reference for the SQL Expression Language. For a full introduction to its usage, see SQL Expression Language Tutorial.

- Column Elements and Expressions
- Selectables, Tables, FROM objects
- Insert, Updates, Deletes
- SQL and Generic Functions
- Column and Data Types